<div align="center">

# Python Nintendo Parental Controls

A simple and generic Python API to authenticate with Nintendo services.

[![Build Status](https://github.com/pantherale0/pynintendoauth/workflows/build/badge.svg)](https://github.com/pantherale0/pynintendoauth/actions)
[![Coverage Status](https://coveralls.io/repos/github/pantherale0/pynintendoauth/badge.svg?branch=main)](https://coveralls.io/github/pantherale0/pynintendoauth?branch=main)
[![PyPi](https://img.shields.io/pypi/v/pynintendoauth)](https://pypi.org/project/pynintendoauth)
[![Licence](https://img.shields.io/github/license/pantherale0/pynintendoauth)](LICENSE)

## Install

```bash
# Install tool
pip3 install pynintendoauth

# Install locally
just install
```